from .删除指定邮件 import 删除指定邮件
from .批量删除指定邮件 import 批量删除指定邮件
from .断开连接 import 断开连接
from .登录 import 登录
from .获取最新一封邮件 import 获取最新一封邮件
from .获取最新五封邮件 import 获取最新五封邮件
from .获取最新十封邮件 import 获取最新十封邮件
from .获取邮件内容 import 获取邮件内容
from .获取邮件数量 import 获取邮件数量
from .获取邮箱占用空间 import 获取邮箱占用空间