from .取CPU型号 import 取CPU型号
from .取内存信息 import 取内存信息
from .取剪辑版内容 import 取剪辑版内容
from .取剪辑版内容到十六进制 import 取剪辑版内容到十六进制
from .取操作系统类别 import 取操作系统类别
from .取时区 import 取时区
from .取用户名 import 取用户名
from .取硬盘特征字 import 取硬盘特征字
from .取系统现行时间 import 取系统现行时间
from .强制关机 import 强制关机
from .强制注销 import 强制注销
from .强制重启 import 强制重启
from .抛出异常 import 抛出异常
from .是否为管理员 import 是否为管理员
from .是否已联网 import 是否已联网
from .清空回收站 import 清空回收站
from .生成随机mac import 生成随机mac
from .置剪辑版内容 import 置剪辑版内容
from .获取外网IP import 获取外网IP
from .获取机器码 import 获取机器码
from .设置系统DNS import 设置系统DNS
