化学_水的沸点 = 100  # 水的沸点，单位：摄氏度
化学_水的结冰点 = 0  # 水的结冰点，单位：摄氏度
化学_摩尔气体体积 = 22.414  # 摩尔气体体积，单位：升
化学_理想气体常数 = 0.0821  # 理想气体常数，单位：L·atm/(mol·K)
化学_水的比热容 = 4.186  # 水的比热容，单位：J/(g·K)
化学_电子质量 = 9.10938356e-31  # 电子质量，单位：kg
化学_质子质量 = 1.6726219e-27  # 质子质量，单位：kg
化学_中子质量 = 1.67492749804e-27  # 中子质量，单位：kg
化学_氧气的摩尔质量 = 32.0  # 氧气的摩尔质量，单位：g/mol
化学_碳的原子量 = 12.01  # 碳的原子量，单位：g/mol
化学_氢的原子量 = 1.008  # 氢的原子量，单位：g/mol
化学_氦的原子量 = 4.0026  # 氦的原子量，单位：g/mol
化学_氮的原子量 = 14.007  # 氮的原子量，单位：g/mol
化学_铝的原子量 = 26.9815385  # 铝的原子量，单位：g/mol
化学_硅的原子量 = 28.085  # 硅的原子量，单位：g/mol
化学_磷的原子量 = 30.973761998  # 磷的原子量，单位：g/mol
化学_硫的原子量 = 32.06  # 硫的原子量，单位：g/mol
化学_氯的原子量 = 35.45  # 氯的原子量，单位：g/mol
化学_钾的原子量 = 39.0983  # 钾的原子量，单位：g/mol
化学_钙的原子量 = 40.078  # 钙的原子量，单位：g/mol
化学_氨的摩尔质量 = 17.031  # 氨的摩尔质量，单位：g/mol
化学_甲烷的摩尔质量 = 16.04  # 甲烷的摩尔质量，单位：g/mol
化学_乙醇的摩尔质量 = 46.07  # 乙醇的摩尔质量，单位：g/mol
化学_葡萄糖的摩尔质量 = 180.16  # 葡萄糖的摩尔质量，单位：g/mol
化学_气体常数 = 8.314462618  # 气体常数，单位：J/(mol·K)
化学_法拉第常数 = 96485.33212  # 法拉第常数，单位：C/mol
化学_阿伏伽德罗常数 = 6.02214076e23  # 阿伏伽德罗常数，单位：mol^-1
化学_氢键能量 = 21  # 氢键能量，单位：kJ/mol
化学_水的密度 = 1  # 水的密度，单位：g/cm³
化学_水的蒸发热 = 40.79  # 水的蒸发热，单位：kJ/mol
化学_水的熔化热 = 6.01  # 水的熔化热，单位：kJ/mol
化学_普朗克常数 = 6.62607015e-34  # 普朗克常数，单位：J·s
化学_玻尔兹曼常数 = 1.380649e-23  # 玻尔兹曼常数，单位：J/K
化学_电子电荷 = 1.602176634e-19  # 电子电荷，单位：C